@@ -3,6 +3,7 @@ import os
 import re
 import sys
 
+from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.core.urlresolvers import get_mod_func
 from django.utils.encoding import smart_str
@@ -12,6 +13,13 @@ from django.utils.importlib import import_module
 _callable_cache = {}  # Maps view and url pattern names to their view functions.
 
 
+HOST_SCHEME = getattr(settings, 'HOST_SCHEME', '//')
+if HOST_SCHEME.endswith(':'):
+    HOST_SCHEME = '%s//' % HOST_SCHEME
+if '//' not in HOST_SCHEME:
+    HOST_SCHEME = '%s://' % HOST_SCHEME
+
+
 def module_has_submodule(package, module_name):
     """See if 'module' is in 'package'."""
     name = ".".join([package.__name__, module_name])
@@ -153,6 +161,7 @@ class host(object):
         host_patterns = patterns('path.to',
             host(r'www', 'urls.default', name='default'),
             host(r'api', 'urls.api', name='api'),
+            host(r'admin', 'urls.admin', name='admin', scheme='https://'),
         )
 
     :param regex: a regular expression to be used to match the request's
@@ -165,8 +174,13 @@ class host(object):
     :type callback: callable or str
     :param prefix: the prefix to apply to the ``urlconf`` parameter
     :type prefix: str
+    :param scheme: the scheme to prepend host names with during reversing,
+                   e.g.  when using the host_url() template tag. Defaults to
+                   :attr:`~django.conf.settings.HOST_SCHEME`.
+    :type scheme: str
     """
-    def __init__(self, regex, urlconf, name, callback=None, prefix=''):
+    def __init__(self, regex, urlconf, name, callback=None, prefix='',
+                 scheme=HOST_SCHEME):
         """
         Compile hosts. We add a literal fullstop to the end of every
         pattern to avoid rather unwieldy escaping in every definition.
@@ -175,6 +189,7 @@ class host(object):
         self.compiled_regex = re.compile(r'%s(\.|$)' % regex)
         self.urlconf = urlconf
         self.name = name
+        self.scheme = scheme
         if callable(callback):
             self._callback = callback
         else:
@@ -182,7 +197,7 @@ class host(object):
         self.add_prefix(prefix)
 
     def __repr__(self):
-        return smart_str(u'<%s %s: %s (%r)>' %
+        return smart_str('<%s %s: %s (%r)>' %
                          (self.__class__.__name__, self.name,
                           self.urlconf, self.regex))
 
@@ -194,12 +209,12 @@ class host(object):
             return lambda *args, **kwargs: None
         try:
             self._callback = get_callable(self._callback_str)
-        except ImportError, e:
+        except ImportError as e:
             mod_name, _ = get_mod_func(self._callback_str)
             raise ImproperlyConfigured("Could not import '%s'. "
                                        "Error was: %s" %
                                        (mod_name, str(e)))
-        except AttributeError, e:
+        except AttributeError as e:
             mod_name, func_name = get_mod_func(self._callback_str)
             raise ImproperlyConfigured("Tried '%s' in module '%s'. "
                                        "Error was: %s" %
